"""Metadata Objects for Spoofy Archiver."""

from .models import (
    AlbumListResult,
    MetadataAlbum,
    MetadataAlbumSummary,
    MetadataArtist,
    MetadataPlaylist,
    MetadataTrack,
    MetadataTrackFile,
    MetadataTrackList,
    MetadataTrackSummary,
)

__all__ = [
    "AlbumListResult",
    "MetadataAlbum",
    "MetadataAlbumSummary",
    "MetadataArtist",
    "MetadataPlaylist",
    "MetadataTrack",
    "MetadataTrackFile",
    "MetadataTrackList",
    "MetadataTrackSummary",
]
